<?php
namespace Teknisa\DF\Modules\Entrada\Controllers;

use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Teknisa\DF\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\DF\Modules\Entrada\Services\Dfe47000LiberacaoParaFinanceiroService;
use Zeedhi\Framework\DTO\Response;

class Dfe47000LiberacaoParaFinanceiroController extends TeknisaCrud
{
    protected $dfe47000LiberacaoParaFinanceiroService;
    
    public function __construct($crudService, $parameterBag, Dfe47000LiberacaoParaFinanceiroService  $dfe47000LiberacaoParaFinanceiroService) {
        parent::__construct($crudService, $parameterBag);
        $this->dfe47000LiberacaoParaFinanceiroService = $dfe47000LiberacaoParaFinanceiroService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $conditions = $request->getFilterCriteria()->getConditions();
        $dataset = $this->dfe47000LiberacaoParaFinanceiroService->find($conditions);
        $response->addDataset(new DataSet('find_Liberacao', $dataset));
    }
    
    public function getFilter(DTO\Request\Filter $request, DTO\Response $response) {
        $filter = $this->dfe47000LiberacaoParaFinanceiroService->getFilter();
        $response->addDataset(new DataSet('filter_liberacao', $filter));
    }
    
    public function liberarTitulos(DTO\Request\DataSet $request, DTO\Response $response) {
        $rows = $request->getDataSet()->getRows();
        $notas = array();
        foreach($rows as $nota) {
            if($nota["IDBLOQNFFIN"] == 'B') array_push($notas, $nota);
        }
        if($notas) {
            $retorno = $this->dfe47000LiberacaoParaFinanceiroService->setAprovacao($notas, 'L');
            $response->addMessage(new Response\Message($retorno["SUCESSOS"]));
            $response->addDataset(new DataSet('erros_aprovacao', $retorno["ERROS"]));
        } 
        else {
            $response->addMessage(new Response\Message("Nenhum dos titulos selecionados pode ser liberado."));
            $response->addDataset(new DataSet('erros_aprovacao', array()));
        }
    }
    
    public function bloquearTitulos(DTO\Request\DataSet $request, DTO\Response $response) {
        $rows  = $request->getDataSet()->getRows();
        $notas = array();
        foreach($rows as $nota) {
            if($nota["IDBLOQNFFIN"] == 'L') array_push($notas, $nota);
        }
        if($notas) {
            $retorno = $this->dfe47000LiberacaoParaFinanceiroService->setAprovacao($notas, 'B');
            $response->addMessage(new Response\Message($retorno["SUCESSOS"]));
            $response->addDataset(new DataSet('erros_aprovacao', $retorno["ERROS"]));
        } 
        else {
            $response->addMessage(new Response\Message("Nenhum dos titulos selecionados pode ser bloqueado."));
            $response->addDataset(new DataSet('erros_aprovacao', array()));
        }
    }
    
}