<?php

namespace Teknisa\DF\Modules\Saida\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\DF\Modules\Saida\Services\Dfs65001CertificadoDigitalService;
use Teknisa\Libs\Util\Utilities;

class Dfs65001CertificadoDigitalController extends \Teknisa\DF\Controllers\TeknisaCrud {
    
    protected $uploadDirectory;
    protected $pathDirectory;
    protected $paramNfseInscmuniService;
    
    public function __construct($crudService, $parameterBag, $uploadDirectory, $pathDirectory, Dfs65001CertificadoDigitalService $certificadoDigitalService, $environment) {
        $this->uploadDirectory = $uploadDirectory;
        $this->pathDirectory = $pathDirectory;
        $this->certificadoDigitalService = $certificadoDigitalService;
        $this->environment = $environment;
    }

    public function saveCertificadoLocal(Row $row, Response $response)
    {
        try
        {
            $row = $row->getRow();
            $filesUploaded = 0;
            if(isset($row['CERTIFICADO']) && $row['CERTIFICADO'])
            {
                $cdempresa = $row["CDEMPRESA"];
                $cdinscmuni = $row["CDINSCMUNI"];
                $cdinscmuni = str_replace(array("-", "/", ".", " "), "", $cdinscmuni);
                $nrorg = (isset($row["NRORG"])) ? $row["NRORG"] : $this->environment->getNrOrgTrab();
                
                foreach($row['CERTIFICADO'] as $fileData)
                {
                    $destinationFolder = $this->uploadDirectory."org_".$nrorg.DIRECTORY_SEPARATOR.$cdempresa."_".$cdinscmuni;
                    if ($file = $this->certificadoDigitalService->factoryFromFileData($cdinscmuni, $cdempresa,
                        $nrorg, $fileData, $destinationFolder))
                    {
                        $filesUploaded++;
                    }
                }
            }
            
            $response->addMessage(new Response\Message("Anexo inserido com sucesso."));
        }
        catch (\Exception $e)
        {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function createFileDataSet(Row $row, Response $response)
    {
        $row = $row->getRow();
        if($row['IDLOCALSERVIDOR'] == 1) $this->createFileDataSetLocal($row, $response);
        else $this->createFileDataSetFileServer($row, $response);
        
        
    }
    
    private function createFileDataSetLocal($row, $response) {
        $cdempresa = $row["CDEMPRESA"];
        $cdinscmuni = $row["CDINSCMUNI"];
        $cdinscmuni = str_replace(array("-", "/", ".", " "), "", $cdinscmuni);
        $nrorg = (isset($row["NRORG"])) ? $row["NRORG"] : $this->environment->getNrOrgTrab();
        
        $destination = 'http://'.$this->pathDirectory."org_".$nrorg.DIRECTORY_SEPARATOR.$cdempresa."_".$cdinscmuni;
        $directory = $this->uploadDirectory."org_".$nrorg.DIRECTORY_SEPARATOR.$cdempresa."_".$cdinscmuni;
        $dataset = array();
        try
        {
            $diret = dir($directory);
            while (false !== ($entry = $diret->read()))
            {
                if($entry != "." && $entry != "..")
                {
                    $dataset[] = array("path" => $destination.DIRECTORY_SEPARATOR.$entry, "fileName" => $entry, "dir" => $directory, "CDEMPRESA" => $cdempresa, "CDINSCMUNI" => $row["CDINSCMUNI"], "NRORG" => $nrorg);
                }
            }

            $response->addDataSet(new DataSet("paramnfse_certDig", $dataset));
        }
        catch(\Exception $e)
        {
            $response->addDataSet(new DataSet("paramnfse_certDig", $dataset));
        }
    }
    
    private function createFileDataSetFileServer($row, $response) {
        $empresa      = $row['CDEMPRESA'];
        $cdinscmuni   = $row['CDINSCMUNI'];
        $nrorg = (isset($row["NRORG"])) ? $row["NRORG"] : $this->environment->getNrOrgTrab();
        
        $inscrMunicip = $this->certificadoDigitalService->getInscrMunicip($cdinscmuni, $empresa, $nrorg, true);
        $fileDataset  = $this->certificadoDigitalService->createFileDataSet($inscrMunicip);

        $response->addDataSet(new DataSet("paramnfse_certDig", $fileDataset));
    }

    public function deleteFile(Row $row, Response $response)
    {
        $row = $row->getRow();
        if($row['IDLOCALSERVIDOR'] == '1') {
            $this->deleteFileLocal($row, $response);
        }
        else {
            $this->deleteFileFileServer($row, $response);
        }
    }
    
    private function deleteFileLocal($row, $response) {
        try
        {
            $checa = unlink($row["dir"].DIRECTORY_SEPARATOR.$row["fileName"]);
            $checa = unlink($row["dir"].DIRECTORY_SEPARATOR.'certKey.pem');
            if(count(scandir($row["dir"])) <= 2)
            {
                rmdir($row["dir"]);
            }

            $response->addMessage(new Response\Message("Anexo removido."));
        }
        catch (\Exception $e)
        {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    private function deleteFileFileServer($row, $response) {
        try {
            $this->certificadoDigitalService->deleteFileFileServer($row);
            $response->addMessage(new Response\Message("Anexo removido."));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
        
    }
    
    public function saveCerticadoFileServer(Row $row, Response $response) {
        try {
            $row          = $row->getRow();
            $this->certificadoDigitalService->saveCertificadoFileServer($row);
            $response->addMessage(new Response\Message("Anexo inserido."));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
        
    }
    
    private function getArrayFiles($filesString, $getLink = false, $mode = 'prod') {
        return $this->certificadoDigitalService->getArrayFiles($filesString);
    }
}